==> ws-v3.20-3-src.tar.gz: ws-v3.20-3/src/perllib/mpfc.h <==
#include <WScom.h>
#include <WSDappDev.h>
#include <WSCbase.h>
#include <WSCbaseList.h>
#include <WSCwindow.h>
#include <WSCform.h>
#include <WSCvbtn.h>
#include <WSCstring.h>
#include <WSCverbList.h>
#include <WSCdirTree.h>
#include <WSCdialog.h>
#include <WSCmessageDialog.h>
#include <WSCinputDialog.h>
#include <WSCindexForm.h>
#include <WSCsform.h>
#include <WSCwizardDialog.h>
#include <WSCworkingDialog.h>
#include <WSCfileSelect.h>
#include <WSCmainWindow.h>
#include <WSCcheckGroup.h>
#include <WSChorzForm.h>
#include <WSCmenuArea.h>
#include <WSCtform.h>
#include <WSCfform.h>
#include <WSCprform.h>
#include <WSCtextField.h>
#include <WSCvmifield.h>
#include <WSCvfbtn.h>
#include <WSCvkflabel.h>
#include <WSCvkslabel.h>
#include <WSDkeyboard.h>
#include <WSCvpifield.h>
#include <WSCvscrBar.h>
#include <WSCvarc.h>
#include <WSCvrect.h>
#include <WSCvline.h>
#include <WSCvpoly.h>
#include <WSCvmeter.h>
#include <WSCvslider.h>
#include <WSCvscrBar.h>
#include <WSCpulldownMenu.h>
#include <WSCvclock.h>
#include <WSCoption.h>
#include <WSCcomboBox.h>
#include <WSCgrid.h>
#include <WSCvimage.h>
#include <WSCvdrawingArea.h>
#include <WSCvtimer.h>
#include <WSCvspace.h>
#include <WSCvballoonHelp.h>
#include <WSCvcsocket.h>
#include <WSCvssocket.h>
#include <WSCvudpsocket.h>
#include <WSCvremoteClient.h>
#include <WSCvremoteServer.h>
#include <WSCvdb.h>
#include <WSCvbarGraph.h>
#include <WSCvlineGraph.h>
#include <WSCvgraphScale.h>
#include <WSCvgraphMatrix.h>
#include <WSCvarrow.h>
#include <WSClocaleSet.h>
#include <WSCcolorSet.h>
#include <WSCfontSet.h>
#include <WSCimageSet.h>

==> ws-v3.20-4-src.tar.gz: ws-v3.20-4/src/perllib/mpfc.h <==
#ifdef MSW
#ifdef open
#undef open
#endif
#ifdef read
#undef read
#endif
#ifdef write
#undef write
#endif
#ifdef close
#undef close
#endif
#ifdef tell
#undef tell
#endif
#ifdef eof
#undef eof
#endif
#ifdef accept
#undef accept
#endif
#ifdef connect
#undef connect
#endif
#ifdef listen
#undef listen
#endif
#ifdef exit
#undef exit
#endif
#endif //MSW


#include <WScom.h>
#include <WSDappDev.h>
#include <WSCbase.h>
#include <WSCbaseList.h>
#include <WSCwindow.h>
#include <WSCform.h>
#include <WSCvbtn.h>
#include <WSCstring.h>
#include <WSCverbList.h>
#include <WSCdirTree.h>
#include <WSCdialog.h>
#include <WSCmessageDialog.h>
#include <WSCinputDialog.h>
#include <WSCindexForm.h>
#include <WSCsform.h>
#include <WSCwizardDialog.h>
#include <WSCworkingDialog.h>
#include <WSCfileSelect.h>
#include <WSCmainWindow.h>
#include <WSCcheckGroup.h>
#include <WSChorzForm.h>
#include <WSCmenuArea.h>
#include <WSCtform.h>
#include <WSCfform.h>
#include <WSCprform.h>
#include <WSCtextField.h>
#include <WSCvmifield.h>
#include <WSCvfbtn.h>
#include <WSCvkflabel.h>
#include <WSCvkslabel.h>
#include <WSDkeyboard.h>
#include <WSCvpifield.h>
#include <WSCvscrBar.h>
#include <WSCvarc.h>
#include <WSCvrect.h>
#include <WSCvline.h>
#include <WSCvpoly.h>
#include <WSCvmeter.h>
#include <WSCvslider.h>
#include <WSCvscrBar.h>
#include <WSCpulldownMenu.h>
#include <WSCvclock.h>
#include <WSCoption.h>
#include <WSCcomboBox.h>
#include <WSCgrid.h>
#include <WSCvimage.h>
#include <WSCvdrawingArea.h>
#include <WSCvtimer.h>
#include <WSCvspace.h>
#include <WSCvballoonHelp.h>
#include <WSCvcsocket.h>
#include <WSCvssocket.h>
#include <WSCvudpsocket.h>
#include <WSCvremoteClient.h>
#include <WSCvremoteServer.h>
#include <WSCvdb.h>
#include <WSCvbarGraph.h>
#include <WSCvlineGraph.h>
#include <WSCvgraphScale.h>
#include <WSCvgraphMatrix.h>
#include <WSCvarrow.h>
#include <WSClocaleSet.h>
#include <WSCcolorSet.h>
#include <WSCfontSet.h>
#include <WSCimageSet.h>
#include <WSDmouse.h>
